import pickle
import fasttext
from numpy import array





if __name__ == "__main__":
    # #load pre-trained fasttext bin model
    model = fasttext.load_model('./fasttext_vec20_model.bin')

    text = raw_input("Input:")
    text_vector = array(model[text])
    vector_array = text_vector.reshape(1, -1) # it is a single sample

    #load pre-trained model
    filename = './incall_model.sav'
    loaded_model = pickle.load(open(filename, 'rb'))
    if loaded_model.predict(vector_array) == 1.:
        print True
    else:
        print False






#
# # result = loaded_model.predict(vector)
# # print result




from distutils.core import setup
setup(
  name = 'dig_indicator_incall',
  packages = ['dig_indicator_incall'], # this must be the same as the name above
  version = '1.2',
  description = 'Domain: indicator',
  author = 'Jiayuan Ding',
  author_email = 'jiayuand@usc.edu',
  url = 'https://github.com/usc-isi-i2/dig-indicators-data/tree/master/Code/dig_indicator_incall', #github 
  download_url = 'https://github.com/usc-isi-i2/dig_indicator_incall/tree/master/Code/dig_indicator_incall/archive/1.2.tar.gz', # I'll explain this in a second
  keywords = ['incall', 'domain', 'dig'], # arbitrary keywords
  classifiers = [],
)
